==> maxdb-source-7_6_00_09.tgz: V76_00_09/MaxDB_ORG/sys/src/SAPDB/DBM/Srv/Commands/Dbm/Shm/DBMSrvCmdDbmShm_DbmShmReset.cpp <==
/*!
  \file    DBMSrvCmdDbmShm_DbmShmReset.cpp
  \author  MarcW
  \ingroup DBMServer commands for administration of shared memory
  \brief   reset shared memory (basically delete the shared memory files)

    ========== licence begin  GPL
    Copyright (C) 2002-2004 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end
*/

#include "hcn20.h"

#include "SAPDB/DBM/Srv/SharedMemory/DBMSrvShM_ShmAdmin.hpp"
#include "SAPDB/DBM/Srv/Commands/Dbm/Shm/DBMSrvCmdDbmShm_DbmShmReset.hpp"
#include "SAPDB/DBM/Srv/SharedMemory/DBMSrvShM_Persistence.hpp"

DBMSrvCmdDbmShm_DbmShmReset::DBMSrvCmdDbmShm_DbmShmReset()
    : DBMSrv_Command( DBMSrv_Command::KeyDbmShmReset, false ) 
{
    m_longHelp =
        "@command dbm_shm_reset This command resets the DBM shared memory by deleting "
            "the DBM shared memory's representation on the file system. It is "
            "to be used only in case of DBM shared memory related problems."
        "@preconditions You have the server authorization SharedMemoryAdmin."
        "@syntax dbm_shm_reset"
        "@reply OK";
}

tcn00_Error DBMSrvCmdDbmShm_DbmShmReset::run(
    VControlDataT * vcontrol,
    CommandT      * command,
    DBMSrv_Reply  & theReply) {

    theReply.startWithOK();
    Msg_List errList;
    
    DBMSrvShM_Persistence* pPers = DBMSrvShM_ShmAdmin::getShmPersistence();
    tcn002_XpValueString runDir;
    cn20XParamGetValue(
            cn00DBMServerData::vcontrol()->dbname,
            PAN_RUNDIR,
            runDir);
    pPers->setRootDir(runDir.asCharp());

    //bool persEx;
    //if( !pPers->exists(persEx, errList) ) {
    if( !pPers->remove(errList) ) {
        delete pPers;
        return theReply.startWithMessageList(errList);
    }

    delete pPers;    
    return OK_CN00;
}

==> maxdb-source-7_6_00_37.tgz: V76_00_37/MaxDB_ORG/sys/src/SAPDB/DBM/Srv/Commands/Dbm/Shm/DBMSrvCmdDbmShm_DbmShmReset.cpp <==
/*!
  \file    DBMSrvCmdDbmShm_DbmShmReset.cpp
  \author  MarcW
  \ingroup DBMServer commands for administration of shared memory
  \brief   reset shared memory (basically delete the shared memory files)

    ========== licence begin  GPL
    Copyright (c) 2002-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

*/

#include "SAPDB/DBM/Srv/Commands/Dbm/Shm/DBMSrvCmdDbmShm_DbmShmReset.hpp"

DBMSrvCmdDbmShm_DbmShmReset::DBMSrvCmdDbmShm_DbmShmReset()
    : DBMSrv_Command( DBMSrv_Command::KeyDbmShmReset, true ) 
{
    m_longHelp =
        "@command dbm_shm_reset This command is obsolete."
        "@syntax dbm_shm_reset"
        "@reply OK";
}

tcn00_Error DBMSrvCmdDbmShm_DbmShmReset::run(
    VControlDataT * vcontrol,
    CommandT      * command,
    DBMSrv_Reply  & theReply) {

    theReply.startWithOK();
    return OK_CN00;
}
